OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ενσωματωμένο μήνυμα %s",
    "Important mail" : "Σημαντική αλληλογραφία",
    "No message found yet" : "Δε βρέθηκε μήνυμα ακόμη.",
    "Set up an account" : "Ρυθμίστε ένα λογαριασμό",
    "Unread mail" : "Μη αναγνωσμένη αλληλογραφία",
    "Important" : "Σημαντικό ",
    "Work" : "Εργασία",
    "Personal" : "Προσωπικό",
    "To Do" : "Προς Ενέργεια",
    "Later" : "Αργότερα",
    "Mail" : "Αλληλογραφία",
    "Mails" : "Ηλ.Αλληλογραφία",
    "💌 A mail app for Nextcloud" : "Εφαρμογή ηλ.ταχυδρομείου για το Nextcloud",
    "Drafts are saved in:" : "Τα πρόχειρα αποθηκεύονται σε:",
    "Sent messages are saved in:" : "Τα απεσταλμένα μηνύματα αποθηκεύονται σε:",
    "Deleted messages are moved in:" : "Τα διαγραμμένα μηνύματα μετακινούνται σε:",
    "Connecting" : "Συνδέεται",
    "Sign in with Google" : "Σύνδεση με την Google",
    "Save" : "Αποθήκευση",
    "Connect" : "Σύνδεση",
    "Password required" : "Απαιτείται συνθηματικό",
    "IMAP server is not reachable" : "Ο διακομιστής IMAP δεν είναι προσβάσιμος",
    "SMTP server is not reachable" : "Ο διακομιστής SMTP δεν είναι προσβάσιμος",
    "SMTP username or password is wrong" : "Το όνομα χρήστη ή ο κωδικός πρόσβασης SMTP είναι λάθος",
    "IMAP connection failed" : "Η σύνδεση IMAP απέτυχε",
    "SMTP connection failed" : "Η σύνδεση SMTP απέτυχε",
    "There was an error while setting up your account" : "Παρουσιάστηκε σφάλμα κατά τη ρύθμιση του λογαριασμού σας",
    "Auto" : "Αυτόματα",
    "Name" : "Όνομα",
    "Mail address" : "Διεύθυνση αλληλογραφίας",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Εισάγετε ένα email με τη μορφή name@example.com",
    "Password" : "Συνθηματικό",
    "Manual" : "Χειροκίνητα",
    "IMAP Settings" : "Ρυθμίσεις IMAP ",
    "IMAP Host" : "Διακομιστής IMAP",
    "IMAP Security" : "Ασφάλεια IMAP",
    "None" : "Καμμία",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Πόρτα IMAP",
    "IMAP User" : "Χρήστης IMAP",
    "IMAP Password" : "Συνθηματικό IMAP",
    "SMTP Settings" : "Ρυθμίσεις SMTP ",
    "SMTP Host" : "Διακομιστής SMTP",
    "SMTP Security" : "Ασφάλεια SMTP ",
    "SMTP Port" : "Πόρτα SMTP",
    "SMTP User" : "Χρήστης SMTP",
    "SMTP Password" : "Συνθηματικό SMTP",
    "Account settings" : "Ρυθμίσεις λογαριασμού",
    "Aliases" : "Ψευδώνυμα",
    "Signature" : "Υπογραφή",
    "A signature is added to the text of new messages and replies." : "Μια υπογραφή προστίθεται στο κείμενο των νέων μηνυμάτων και των απαντήσεων.",
    "Writing mode" : "Κατάσταση επεξεργασίας",
    "Preferred writing mode for new messages and replies." : "Προτιμώμενη λειτουργία σύνταξης για νέα μηνύματα και απαντήσεις.",
    "Default folders" : "Προεπιλεγμένοι φάκελοι",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Αυτοματοποιημένη απάντηση σε εισερχόμενα μηνύματα. Εάν κάποιος σας στείλει πολλά μηνύματα, αυτή η αυτοματοποιημένη απάντηση θα αποστέλλεται το πολύ μία φορά κάθε 4 ημέρες.",
    "Filters" : "Φίλτρα",
    "Mail server" : "Διακομιστής αλληλογραφίας",
    "Update alias" : "Ενημέρωση ψευδώνυμου",
    "Show update alias form" : "Εμφάνιση φόρμας ενημέρωσης ψευδώνυμου",
    "Delete alias" : "Διαγραφή ψευδωνύμου",
    "Go back" : "Πίσω",
    "Change name" : "Αλλαγή ονόματος",
    "Email address" : "Διεύθυνση αλληλογραφίας",
    "Add alias" : "Προσθήκη alias",
    "Create alias" : "Δημιουργία ψευδωνύμου",
    "Cancel" : "Ακύρωση",
    "Put my text to the bottom of a reply instead of on top of it." : "Το κείμενό μου στο κάτω μέρος μιας απάντησης αντί στο επάνω μέρος της.",
    "Could not update preference" : "Δεν ήταν δυνατή η ενημέρωση της προτίμησης",
    "Mail settings" : "Ρυθμίσεις αλληλογραφίας",
    "Accounts" : "Λογαριασμοί",
    "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
    "General" : "Γενικά",
    "List" : "Λίστα",
    "Sorting" : "Ταξινόμηση",
    "Newest" : "Νεότερο",
    "Oldest" : "Παλαιότερο",
    "Use Gravatar and favicon avatars" : "Χρησιμοποιήστε Gravatar και favicon avatars",
    "Register as application for mail links" : "Εγγραφή ως εφαρμογή για συνδέσμους αλληλογραφίας",
    "Register" : "Εγγραφή",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Να επιτρέπεται στην εφαρμογή να συλλέγει δεδομένα σχετικά με την δραστηριότητά σας. Με βάση αυτά τα δεδομένα, η εφαρμογή θα προσαρμοστεί στις προτιμήσεις σας. Τα δεδομένα θα αποθηκευτούν μόνο τοπικά.",
    "Trusted senders" : "Έμπιστοι αποστολείς",
    "About" : "Σχετικά με",
    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
    "Compose new message" : "Σύνταξη νέου μηνύματος",
    "Newer message" : "Νεότερο μήνυμα",
    "Older message" : "Παλαιότερο μήνυμα",
    "Toggle star" : "Εναλλαγή αστεριού",
    "Toggle unread" : "Εναλλαγή αδιάβαστων",
    "Archive" : "Αρχειοθετημένα",
    "Delete" : "Διαγραφή",
    "Search" : "Αναζήτηση",
    "Send" : "Αποστολή",
    "Refresh" : "Ανανέωση",
    "Send later" : "Αποστολή αργότερα",
    "Message {id} could not be found" : "Δεν ήταν δυνατή η εύρεση του μηνύματος {id}",
    "From" : "Από:",
    "Select account" : "Επιλογή λογαριασμού",
    "To" : "Προς",
    "Contact or email address …" : "Επαφή ή διεύθυνση ηλ.ταχυδρομείου ...",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Θέμα",
    "Subject …" : "Θέμα...",
    "This message came from a noreply address so your reply will probably not be read." : "Η αλληλογραφία προέρχεται από διεύθυνση η οποία δεν δέχεται απαντήσεις, οπότε η απάντησή σας πιθανότατα δεν θα διαβαστεί.",
    "The following recipients do not have a PGP key: {recipients}." : "Οι ακόλουθοι παραλήπτες δεν έχουν κλειδί PGP: {recipients}.",
    "Write message …" : "Συγγραφή μηνύματος ...",
    "Saving draft …" : "Αποθήκευση προχείρου ...",
    "Error saving draft" : "Σφάλμα κατά την αποθήκευση του προχείρου",
    "Draft saved" : "Το πρόχειρο αποθηκεύτηκε",
    "Save draft" : "Αποθήκευση ως πρόχειρο",
    "Discard & close draft" : "Απόρριψη & κλείσιμο πρόχειρου",
    "Enable formatting" : "Ενεργοποίηση μορφοποίησης",
    "Upload attachment" : "Μεταφόρτωση συνημμένων",
    "Add attachment from Files" : "Προσθήκη συνημμένου από Αρχεία",
    "Request a read receipt" : "Ζητήστε βεβαίωση ανάγνωσης",
    "Encrypt message with Mailvelope" : "Κρυπτογράφηση μηνύματος με το Mailvelope",
    "Send now" : "Αποστολή τωρα",
    "Tomorrow morning" : "Αύριο το πρωί",
    "Tomorrow afternoon" : "Αύριο το απόγευμα",
    "Monday morning" : "Δευτέρα πρωί",
    "Custom date and time" : "Επιλέξτε ημερομηνία και ώρα",
    "Enter a date" : "Προσθέστε ημερομηνία",
    "Choose" : "Επιλογή",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Το συνημμένο υπερβαίνει το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε το αρχείο μέσω συνδέσμου.","Τα συνημμένα υπερβαίνουν το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε τα αρχεία μέσω συνδέσμου."],
    "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
    "Choose a file to share as a link" : "Επιλέξτε ένα αρχείο για κοινή χρήση ως σύνδεσμο",
    "_{count} attachment_::_{count} attachments_" : ["{count} συνημμένo","{count} συνημμένα"],
    "Confirm" : "Επιβεβαίωση",
    "Plain text" : "Απλό κείμενο",
    "Rich text" : "Εμπλουτισμένο κείμενο",
    "No messages in this folder" : "Δεν έχει μηνύματα ο φάκελος",
    "No messages" : "Κανένα μήνυμα",
    "Blind copy recipients only" : "Αποδέκτες με κρυφή κοινοποίηση μόνο",
    "No subject" : "Χωρίς θέμα",
    "Later today – {timeLocale}" : "Αργότερα σήμερα – {timeLocale}",
    "Set reminder for later today" : "Ορισμός υπενθύμισης για αργότερα σήμερα",
    "Tomorrow – {timeLocale}" : "Αύριο – {timeLocale}",
    "Set reminder for tomorrow" : "Ορισμός υπενθύμισης για αύριο",
    "This weekend – {timeLocale}" : "Αυτή την εβδομάδα – {timeLocale}",
    "Set reminder for this weekend" : "Ορίστε υπενθύμιση για αυτό το Σαββατοκύριακο",
    "Next week – {timeLocale}" : "Επόμενη εβδομάδα – {timeLocale}",
    "Set reminder for next week" : "Ορίστε υπενθύμιση για την επόμενη εβδομάδα",
    "Could not delete message" : "Δεν ήταν δυνατή η διαγραφή του μηνύματος",
    "Could not archive message" : "Δεν ήταν δυνατή η αρχειοθέτηση του μηνύματος",
    "Unfavorite" : "Μη αγαπημένο",
    "Favorite" : "Αγαπημένο",
    "Unread" : "Μη αναγνωσμένο",
    "Read" : "Αναγνωσμένο",
    "Unimportant" : "Μη σημαντικό",
    "Mark not spam" : "Σήμανση ως μη ανεπιθύμητο",
    "Mark as spam" : "Σήμανση ως ανεπιθύμητο",
    "Edit tags" : "Επεξεργασία ετικετών",
    "Move thread" : "Μετακίνηση νήματος",
    "Delete thread" : "Διαγραφή νήματος",
    "Delete message" : "Διαγραφή μηνύματος",
    "More actions" : "Περισσότερες ενέργειες",
    "Back" : "Πίσω",
    "Edit as new message" : "Επεξεργασία ως νέο μήνυμα",
    "Create event" : "Δημιουργία συμβάντος",
    "Create task" : "Δημιουργία εργασίας",
    "Download message" : "Λήψη μηνύματος",
    "Load more" : "Φόρτωση περισσότερων",
    "_Mark {number} read_::_Mark {number} read_" : ["Επισήμανση {number} ως αναγνωσμένου","Επισήμανση {number} ως αναγνωσμένων"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Επισήμανση {number} ως μη αναγνωσμένου","Επισήμανση {number} ως μη αναγνωσμένων"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Επισήμανση {number} ως σημαντικού","Επισήμανση {number} ως σημαντικών"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Επισήμανση {number} ως μη σημαντικού","Επισήμανση {number} ως μη σημαντικών"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Μη αγαπημένο {number}","Μη αγαπημένα {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Αγαπημένο {number}","Αγαπημένα {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Αναίρεση επιλογής {number}","Αναίρεση επιλογών {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Μετακίνηση {number} νημάτος","Μετακίνηση {number} νημάτων"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Προώθηση {number} ως συνημμένο","Προώθηση {number} ως συνημμένων"],
    "Report this bug" : "Αναφέρετε αυτό το σφάλμα",
    "Event created" : "Το συμβάν δημιουργήθηκε",
    "Could not create event" : "Αδυναμία δημιουργίας συμβάντος",
    "All day" : "Ολοήμερο",
    "Description" : "Περιγραφή",
    "Create" : "Δημιουργία",
    "This event was updated" : "Αυτή η εκδήλωση ενημερώθηκε",
    "You accepted this invitation" : "Αποδεχτήκατε αυτήν την πρόσκληση",
    "You tentatively accepted this invitation" : "Αποδεχτήκατε προσωρινά αυτήν την πρόσκληση",
    "You declined this invitation" : "Απορρίψατε αυτήν την πρόσκληση",
    "You already reacted to this invitation" : "Έχετε ήδη αντιδράσει σε αυτήν την πρόσκληση",
    "You have been invited to an event" : "Έχετε προσκληθεί σε μια εκδήλωση",
    "This event was cancelled" : "Αυτή η εκδήλωση ακυρώθηκε",
    "Save to" : "Αποθήκευση σε",
    "Select" : "Επιλογή",
    "Comment" : "Σχόλιο",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Tentatively accept" : "Προσωρινά αποδεχτείτε",
    "More options" : "Περισσότερες επιλογές",
    "domain" : "τομέας",
    "Remove" : "Αφαίρεση",
    "email" : "Ηλ.Ταχυδρομείο",
    "Itinerary for {type} is not supported yet" : "Η διαδρομή για {type} δεν υποστηρίζεται ακόμα",
    "Loading messages …" : "Φόρτωση μηνυμάτων ...",
    "Choose target folder" : "Επιλογή φακέλου προορισμού",
    "No more submailboxes in here" : "Δεν υπάρχουν άλλα υπο-γραμματοκιβώτια εδώ",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Τα μηνύματα θα επισημανθούν αυτόματα ως σημαντικά με βάση αυτά με τα οποία επισημαίνετε ως σημαντικά. Στην αρχή ίσως χρειαστεί να τα αλλάζετε χειροκίνητα, έως ότου εκπαιδευτεί το σύστημα, αλλά θα βελτιώνεται σταδιακά με την πάροδο του χρόνου.",
    "Important info" : "Σημαντική πλροφορία",
    "Other" : "Άλλο",
    "Could not send mdn" : "Αδυναμία αποστολής mdn",
    "The sender of this message has asked to be notified when you read this message." : "Ο αποστολέας του μηνύματος ζήτησε να ειδοποιηθεί όταν διαβάσετε το μήνυμα.",
    "Notify the sender" : "Ειδοποιήστε τον αποστολέα",
    "You sent a read confirmation to the sender of this message." : "Στείλατε βεβαίωση ανάγνωσης στον αποστολέα του μηνύματος.",
    "Forward" : "Προώθηση",
    "Move message" : "Μετακίνηση μηνύματος",
    "Translate" : "Μετάφραση",
    "Forward message as attachment" : "Προώθηση μηνύματος ως συνημμένο",
    "View source" : "Προβολή πηγής",
    "Download thread data for debugging" : "Λήψη δεδομένων νήματος ακολουθίας για εντοπισμό σφαλμάτων",
    "Message body" : "Σώμα μηνύματος",
    "Unnamed" : "Ανώνυμο",
    "Embedded message" : "Ενσωματωμένο μήνυμα",
    "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
    "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
    "Download attachment" : "Λήψη συνημμένου",
    "Save to Files" : "Αποθήκευση στα Αρχεία",
    "Choose a folder to store the attachments in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε μέσα τα συνημμένα",
    "Save all to Files" : "Αποθήκευση όλων στα Αρχεία",
    "Download Zip" : "Λήψη Zip",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Το μήνυμα είναι κρυπτογραφημένο με PGP. Εγκαταστήστε το Mailvelope για αποκρυπτογράφηση.",
    "The images have been blocked to protect your privacy." : "Οι εικόνες έχουν αποκλειστεί για να προστατευθεί η ιδιωτικότητά σας.",
    "Show images" : "Εμφάνιση εικόνων",
    "Show images temporarily" : "Εμφάνιση εικόνων προσωρινά",
    "Always show images from {sender}" : "Εμφάνιση πάντα εικόνων από {sender}",
    "Always show images from {domain}" : "Εμφάνιση πάντα εικόνων από {domain}",
    "Message frame" : "Πλαίσιο κειμένου",
    "Quoted text" : "Κείμενο σε παράθεση",
    "Move" : "Μετακίνηση",
    "Moving" : "Μετακινείται",
    "Moving thread" : "Μετακίνηση νήματος",
    "Moving message" : "Μετακίνηση μηνύματος",
    "Remove account" : "Αφαίρεση λογαριασμού",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Ο λογαριασμός για {email} και προσωρινά αποθηκευμένα δεδομένα email θα καταργηθεί από το Nextcloud, αλλά όχι από τον πάροχο email σας.",
    "Remove {email}" : "Αφαίρεση {email}",
    "Show only subscribed folders" : "Εμφάνιση μόνο εγγεγραμμένων φακέλων",
    "Folder name" : "Όνομα φακέλου",
    "Saving" : "Αποθήκευση",
    "Move up" : "Μετακίνηση επάνω",
    "Move down" : "Μετακίνηση Κάτω",
    "Show all subscribed folders" : "Εμφάνιση όλων των εγγεγραμμένων φακέλων",
    "Show all folders" : "Εμφάνιση όλων των φακέλων",
    "Collapse mailboxes" : "Σύμπτυξη γραμματοκιβωτίων",
    "_{total} message_::_{total} messages_" : ["{total} μήνυμα","{total} μηνύματα"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} μη αναγνωσμένο από {total}","{unread} μη αναγνωσμένα από {total}"],
    "Loading …" : "Φόρτωση…",
    "The folder and all messages in it will be deleted." : "Ο φάκελος και όλα τα μηνύματα σε αυτόν θα διαγραφούν.",
    "Delete folder" : "Διαγραφή φακέλου",
    "Delete folder {name}" : "Διαγραφή του φακέλου {name}",
    "An error occurred, unable to rename the mailbox." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία του γραμματοκιβωτίου.",
    "Mark all as read" : "Σημείωση όλων ως αναγνωσμένων",
    "Mark all messages of this folder as read" : "Σημείωση όλων των μυνημάτων ως αναγνωσμένων",
    "Add subfolder" : "Προσθήκη υποφακέλου",
    "Rename" : "Μετονομασία",
    "Move folder" : "Μετακίνηση φακέλου",
    "Clear cache" : "Εκκαθάριση προσωρινής μνήμης",
    "Clear locally cached data, in case there are issues with synchronization." : "Εκκαθαρίστε τα δεδομένα κρυφής μνήμης, σε περίπτωση που υπάρχουν προβλήματα με το συγχρονισμό.",
    "Subscribed" : "Εγγεγραμμένα",
    "Sync in background" : "Συγχρονισμός στο παρασκήνιο",
    "Outbox" : "Εξερχόμενα",
    "New message" : "Νέο μήνυμα",
    "Edit message" : "Επεξεργασία μηνύματος",
    "Draft" : "Πρόχειρο",
    "Reply" : "Απάντηση",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Προσπαθείτε να στείλετε σε πολλούς παραλήπτες σε Προς και/ή Κοιν. Εξετάστε το ενδεχόμενο να χρησιμοποιήσετε Κρυφή κοιν. για να αποκρύψετε τις διευθύνσεις παραληπτών.",
    "Message discarded" : "Το μήνυμα απορρίφθηκε",
    "Could not discard message" : "Δεν ήταν δυνατή η απόρριψη του μηνύματος",
    "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
    "Retry" : "Δοκιμή ξανά",
    "Send anyway" : "Στείλτε ούτως ή άλλως",
    "Message" : "Μήνυμα",
    "Could not open outbox" : "Αδυναμία ανοίγματος εξερχομένων",
    "Pending or not sent messages will show up here" : "Εδώ εμφανίζονται μηνύματα που εκκρεμούν ή δεν έχουν σταλεί",
    "Message could not be sent" : "Δεν ήταν δυνατή η αποστολή του μηνύματος",
    "Message deleted" : "Το μήνυμα διαγράφτηκε",
    "Contacts with this address" : "Επαφές με αυτήν τη διεύθυνση",
    "Add to Contact" : "Προσθήκη στις επαφές",
    "New Contact" : "Νέα επαφή",
    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
    "Contact name …" : "Όνομα επαφής ...",
    "Add" : "Προσθήκη",
    "Show less" : "Εμφάνιση λιγότερων",
    "Show more" : "Εμφάνιση περισσότερων",
    "Clear" : "Εκκαθάριση",
    "Close" : "Κλείσιμο",
    "Body" : "Σώμα",
    "Date" : "Ημερομηνία",
    "Tags" : "Ετικέτες",
    "Select tags" : "Επιλέξτε ετικέτες",
    "Last 7 days" : "Τελευταίες 7 ημέρες",
    "Custom" : "Προσαρμοσμένο",
    "Sieve User" : "Χρήστης Sieve",
    "Signature …" : "Υπογραφή...",
    "Save signature" : "Αποθήκευση υπογραφής",
    "Message source" : "Πηγή μηνύματος",
    "An error occurred, unable to rename the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία της ετικέτας.",
    "Saving new tag name …" : "Αποθήκευση νέου ονόματος ετικέτας…",
    "Delete tag" : "Διαγραφή ετικέτας",
    "Tag already exists" : "Υπάρχει ήδη η ετικέτα",
    "An error occurred, unable to create the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία της ετικέτας.",
    "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
    "Add tag" : "Προσθήκη ετικέτας",
    "Saving tag …" : "Αποθήκευση ετικέτας…",
    "Could not load your message thread" : "Δεν ήταν δυνατή η φόρτωση του μηνύματός σας",
    "Not found" : "Δεν βρέθηκε",
    "Reply all" : "Απάντηση σε όλους",
    "Unsubscribe" : "Κατάργηση εγγραφής",
    "Reply to sender only" : "Απάντηση μόνο στον αποστολέα",
    "Mark as favorite" : "Επισήμανση ως αγαπημένο",
    "Mark as unread" : "επισήμανση ως μή-αναγνωσμένο",
    "Mark as read" : "Σήμανση ως αναγνωσμένο",
    "Could not remove trusted sender {sender}" : "Δεν ήταν δυνατή η κατάργηση του αξιόπιστου αποστολέα {sender}",
    "No senders are trusted at the moment." : "Κανένας αποστολέας δεν είναι αξιόπιστος αυτή τη στιγμή.",
    "Untitled event" : "Συμβάν χωρίς όνομα",
    "(organizer)" : "(organizer)",
    "Import into {calendar}" : "Εισαγωγή στο {calendar}",
    "Event imported into {calendar}" : "Το συμβάν εισήχθη στο {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Πτήση {flightNr} από {depAirport} προς {arrAirport}",
    "Airplane" : "Αεροπλάνο",
    "Reservation {id}" : "Κράτηση {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} από {depStation} προς {arrStation}",
    "Train from {depStation} to {arrStation}" : "Τρένο από {depStation} προς {arrStation}",
    "Train" : "Τρένο",
    "Flag" : "Σημαία",
    "Recipient" : "Παραλήπτης",
    "Delete filter" : "Διαγραφή φίλτρου",
    "Operator" : "Διαχειριστής",
    "contains" : "περιέχει",
    "matches" : "ταιριάζει",
    "Priority" : "Προτεραιότητα",
    "Mail app" : "Εφαρμογή αλληλογραφίας",
    "The mail app allows users to read mails on their IMAP accounts." : "Η εφαρμογή ταχυδρομείου επιτρέπει στους χρήστες να διαβάζουν μηνύματα από τους λογαριασμούς τους IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Εδώ μπορείτε να βρείτε ρυθμίσεις για το περιστατικό. Οι συγκεκριμένες ρυθμίσεις χρήστη βρίσκονται στην ίδια την εφαρμογή (κάτω αριστερή γωνία).",
    "Reset" : "Επαναφορά",
    "Client ID" : "Αναγνωριστικό πελάτη",
    "Client secret" : "Μυστικό πελάτη",
    "Unlink" : "Αποσύνδεση",
    "Email: {email}" : "Email: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} σε {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} σε {host}:{port} ({ssl} encryption)",
    "IMAP" : "IMAP",
    "User" : "Χρήστης",
    "Host" : "Διακομιστής",
    "Port" : "Θύρα",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "Με τις παραπάνω ρυθμίσεις, η εφαρμογή θα δημιουργήσει τις ρυθμίσεις λογαριασμού με τον ακόλουθο τρόπο:",
    "E-mail address" : "E-mail διεύθυνση",
    "Valid until" : "Έγκυρο έως",
    "Certificate" : "Πιστοποιητικό",
    "Submit" : "Υποβολή",
    "Account connected" : "Συνδεδεμένος λογαριασμός",
    "Connect your mail account" : "Συνδέστε το λογαριασμό αλληλογραφίας σας",
    "All" : "'Ολα",
    "Drafts" : "Πρόχειρα",
    "Favorites" : "Αγαπημένα",
    "Priority inbox" : "Εισερχόμενα προτεραιότητας",
    "All inboxes" : "Όλα τα εισερχόμενα",
    "Inbox" : "Εισερχόμενα",
    "Junk" : "Ανεπιθύμητα",
    "Sent" : "Απεσταλμένα",
    "Trash" : "Απορρίμματα",
    "Error while sharing file" : "Σφάλμα κατά τον διαμοιρασμό αρχείου",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n νεό μήνυμα\nαπό {from}","%n νέα μηνύματα\nαπό {from}"],
    "Nextcloud Mail" : "Αλληλογραφία Nextcloud",
    "Attachments were not copied. Please add them manually." : "Τα συνημμένα δεν αντιγράφηκαν. Προσθέστε τα χειροκίνητα.",
    "Message sent" : "Το μήνυμα στάλθηκε",
    "Could not send message" : "Αδυναμία αποστολής μηνύματος",
    "Could not load {tag}{name}{endtag}" : "Αδυναμία φόρτωσης {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Παρουσιάστηκε πρόβλημα φόρτωσης {tag}{name}{endtag}",
    "Could not load your message" : "Δεν ήταν δυνατή η φόρτωση του μηνύματός σας",
    "Could not load the desired message" : "Αδυναμία φόρτωσης του προτιμώμενου μηνύματος",
    "Could not load the message" : "Δεν ήταν δυνατή η φόρτωση του μηνύματος",
    "Error loading message" : "Σφάλμα φόρτωσης μηνύματος",
    "Forwarding to %s" : "Προώθηση σε %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Κάντε κλικ εδώ εάν δεν ανακατευθυνθείτε αυτόματα μέσα σε λίγα δευτερόλεπτα.",
    "Redirect" : "Ανακατεύθυνση",
    "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
    "Continue to %s" : "Συνέχεια στο %s",
    "No messages in this mailbox" : "Δεν υπάρχουν μηνύματα σε αυτό το γραμματοκιβώτιο.",
    "No trash mailbox configured" : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο απορριμμάτων",
    "Draft: " : "Πρόχειρο:",
    "Could not open mailbox" : "Δεν ήταν δυνατό το άνοιγμα του γραμματοκιβωτίου",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Καταλογοποίηση των μηνυμάτων σας. Αυτό μπορεί να διαρκέσει περισσότερο για μεγαλύτερα γραμματοκιβώτια.",
    "Choose target mailbox" : "Επιλέξτε γραμματοκιβώτιο προορισμού",
    "Show only subscribed mailboxes" : "Εμφάνιση μόνο εγγεγραμμένων γραμματοκιβωτίων",
    "Add mailbox" : "Προσθήκη γραμματοκιβωτίου",
    "Show all subscribed mailboxes" : "Εμφάνιση όλων των εγγεγραμμένων γραμματοκιβωτίων",
    "Show all mailboxes" : "Εμφάνιση όλων των γραμματοκιβωτίων",
    "The mailbox and all messages in it will be deleted." : "Το γραμματοκιβώτιο και όλα τα μηνύματα σε αυτό θα διαγραφούν.",
    "Delete mailbox" : "Διαγραφή γραμματοκιβωτίου",
    "Delete mailbox {name}" : "Διαγραφή γραμματοκιβωτίου {name}",
    "Mark all messages of this mailbox as read" : "Επισήμανση όλων ως αναγνωσμένων",
    "Add submailbox" : "Προσθήκη υπο-γραμματοκιβωτίου",
    "No sent mailbox configured. Please pick one in the account settings." : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο για τα απεσταλμένα μηνύματα. Επιλέξτε ένα από τις ρυθμίσεις λογαριασμού.",
    "Actions" : "Ενέργειες",
    "New action" : "Νέα ενέργεια"
},
"nplurals=2; plural=(n != 1);");
